Error

Enum Error 

pub enum Error {
    Overrun,
}
๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::spi module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::spi module instead.

Variants



Overrun

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::spi module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::spi module instead.