I2CMaster3

Struct I2CMaster3 

pub struct I2CMaster3<P0, P1>
where P0: CompatiblePad<Sercom = SERCOM3, PadNum = Pad0>, P1: CompatiblePad<Sercom = SERCOM3, PadNum = Pad1>,
{ /* private fields */ }
Represents the Sercom instance configured to act as an I2C Master. The embedded_hal blocking I2C traits are implemented by this instance.

Implementations

Source

impl<P0, P1> I2CMaster3<P0, P1>
where P1: CompatiblePad<Sercom = SERCOM3, PadNum = Pad1>, P0: CompatiblePad<Sercom = SERCOM3, PadNum = Pad0>,

pub fn new<F>( clock: &Sercom3CoreClock, freq: F, sercom: SERCOM3, mclk: &mut MCLK, sda: P0, scl: P1, ) -> I2CMaster3<P0, P1>
where F: Into<Hertz>,

Configures the sercom instance to work as an I2C Master. The clock is obtained via the GenericClockGenerator type. freq specifies the bus frequency to use for I2C communication. There are typically a handful of values that tend to be supported; standard mode is 100.khz(), full speed mode is 400.khz(). The hardware in the atsamd device supports fast mode at 1.mhz() and fast mode, but there may be additional hardware configuration missing from the current software implementation that prevents that from working as-written today.

let mut i2c = I2CMaster3::new(
    &clocks.sercom3_core(&gclk0).unwrap(),
    400.khz(),
    p.device.SERCOM3,
    &mut p.device.MCLK,
    // Metro M0 express has I2C on pins PA22, PA23
    pins.pa22.into_pad(&mut pins.port),
    pins.pa23.into_pad(&mut pins.port),
);
pub fn free(self) -> (P0, P1, SERCOM3)

Breaks the sercom device up into its constituent pins and the SERCOM instance. Does not make any changes to power management.