SPIMaster5

Struct SPIMaster5 

pub struct SPIMaster5<MISO, MOSI, SCK> { /* private fields */ }
๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::spi module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::spi module instead.

SPIMasterX represents the corresponding SERCOMX instance configured to act in the role of an SPI Master. Objects of this type implement the HAL FullDuplex and blocking SPI traits.

This type is generic over any valid pad mapping where there is a defined โ€œdata in pin out data out pin outโ€ implementation.

Implementations

Source

impl<MISO, MOSI, SCK> SPIMaster5<MISO, MOSI, SCK>

pub fn new<F, T>( clock: &Sercom5CoreClock, freq: F, mode: Mode, sercom: SERCOM5, mclk: &mut MCLK, padout: T, ) -> SPIMaster5<MISO, MOSI, SCK>
where F: Into<Hertz>, T: Into<Padout<SERCOM5, MISO, MOSI, SCK>>, Padout<SERCOM5, MISO, MOSI, SCK>: DipoDopo,

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::spi module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::spi module instead.

Power on and configure SERCOMX to work as an SPI Master operating with the specified frequency and SPI Mode. The pinout specifies which pins are bound to the MISO, MOSI, SCK functions.

pub fn set_baud<F>(&mut self, freq: F, clock: &Sercom5CoreClock)
where F: Into<Hertz>,

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::spi module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::spi module instead.

Set the baud rate

pub fn free(self) -> (Padout<SERCOM5, MISO, MOSI, SCK>, SERCOM5)

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::spi module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::spi module instead.

Tear down the SPI instance and yield the constituent pins and SERCOM instance. No explicit de-initialization is performed.