UART4

Struct UART4 

pub struct UART4<RX, TX, RTS, CTS> { /* private fields */ }
๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::uart module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::uart module instead.

UARTX represents the corresponding SERCOMX instance configured to act in the role of a UART Master. Objects of this type implement the HAL serial::Read, serial::Write traits.

This type is generic over any valid pad mapping where there is a defined โ€œreceive pin out transmit pin outโ€ implementation.

Implementations

Source

impl<RX, TX, RTS, CTS> UART4<RX, TX, RTS, CTS>

pub fn new<F, T>( clock: &Sercom4CoreClock, freq: F, sercom: SERCOM4, mclk: &mut MCLK, padout: T, ) -> UART4<RX, TX, RTS, CTS>
where F: Into<Hertz>, T: Into<Padout<SERCOM4, RX, TX, RTS, CTS>>, Padout<SERCOM4, RX, TX, RTS, CTS>: RxpoTxpo,

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::uart module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::uart module instead.

pub fn free(self) -> (Padout<SERCOM4, RX, TX, RTS, CTS>, SERCOM4)

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::uart module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::uart module instead.

pub fn split(self) -> (UART4Tx<TX, RTS>, UART4Rx<RX, CTS>)

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::uart module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::uart module instead.

Splits the UART into transmit and receive halves

pub fn join( tx: UART4Tx<TX, RTS>, rx: UART4Rx<RX, CTS>, ) -> UART4<RX, TX, RTS, CTS>

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::uart module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::uart module instead.

Combines transmit and receive halves back into a duplex UART

pub fn intenset<F>(&mut self, f: F)
where F: FnOnce(&mut W<u8, Reg<u8, _INTENSET>>),

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::uart module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::uart module instead.

pub fn intenclr<F>(&mut self, f: F)
where F: FnOnce(&mut W<u8, Reg<u8, _INTENCLR>>),

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::uart module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::uart module instead.

pub fn flags(&self) -> R<u16, Reg<u16, _STATUS>>

๐Ÿ‘ŽDeprecated since 0.13.0:

The sercom::v1::uart module is deprecated, and will be removed in a subsequent release. Please use the sercom::v2::uart module instead.