pub struct SPIMaster5<MISO, MOSI, SCK> { /* private fields */ }The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.
SPIMasterX represents the corresponding SERCOMX instance
configured to act in the role of an SPI Master.
Objects of this type implement the HAL FullDuplex and blocking
SPI traits.
This type is generic over any valid pad mapping where there is a defined โdata in pin out data out pin outโ implementation.
Implementations
Sourceimpl<MISO, MOSI, SCK> SPIMaster5<MISO, MOSI, SCK>
impl<MISO, MOSI, SCK> SPIMaster5<MISO, MOSI, SCK>
Sourcepub fn new<F, T>(
clock: &Sercom5CoreClock,
freq: F,
mode: Mode,
sercom: SERCOM5,
mclk: &mut MCLK,
padout: T,
) -> SPIMaster5<MISO, MOSI, SCK>
๐Deprecated since 0.13.0: The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.
pub fn new<F, T>( clock: &Sercom5CoreClock, freq: F, mode: Mode, sercom: SERCOM5, mclk: &mut MCLK, padout: T, ) -> SPIMaster5<MISO, MOSI, SCK>
The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.
Power on and configure SERCOMX to work as an SPI Master operating with the specified frequency and SPI Mode. The pinout specifies which pins are bound to the MISO, MOSI, SCK functions.
Sourcepub fn set_baud<F>(&mut self, freq: F, clock: &Sercom5CoreClock)
๐Deprecated since 0.13.0: The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.
pub fn set_baud<F>(&mut self, freq: F, clock: &Sercom5CoreClock)
The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.
Set the baud rate
Sourcepub fn free(self) -> (Padout<SERCOM5, MISO, MOSI, SCK>, SERCOM5)
๐Deprecated since 0.13.0: The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.
pub fn free(self) -> (Padout<SERCOM5, MISO, MOSI, SCK>, SERCOM5)
The sercom::v1::spi module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::spi module instead.
Tear down the SPI instance and yield the constituent pins and SERCOM instance. No explicit de-initialization is performed.