pub struct UART4<RX, TX, RTS, CTS> { /* private fields */ }The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
UARTX represents the corresponding SERCOMX instance
configured to act in the role of a UART Master.
Objects of this type implement the HAL serial::Read,
serial::Write traits.
This type is generic over any valid pad mapping where there is a defined โreceive pin out transmit pin outโ implementation.
Implementations
Sourceimpl<RX, TX, RTS, CTS> UART4<RX, TX, RTS, CTS>
impl<RX, TX, RTS, CTS> UART4<RX, TX, RTS, CTS>
pub fn new<F, T>( clock: &Sercom4CoreClock, freq: F, sercom: SERCOM4, mclk: &mut MCLK, padout: T, ) -> UART4<RX, TX, RTS, CTS>
The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
pub fn free(self) -> (Padout<SERCOM4, RX, TX, RTS, CTS>, SERCOM4)
The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
Sourcepub fn split(self) -> (UART4Tx<TX, RTS>, UART4Rx<RX, CTS>)
๐Deprecated since 0.13.0: The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
pub fn split(self) -> (UART4Tx<TX, RTS>, UART4Rx<RX, CTS>)
The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
Splits the UART into transmit and receive halves
Sourcepub fn join(
tx: UART4Tx<TX, RTS>,
rx: UART4Rx<RX, CTS>,
) -> UART4<RX, TX, RTS, CTS>
๐Deprecated since 0.13.0: The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
pub fn join( tx: UART4Tx<TX, RTS>, rx: UART4Rx<RX, CTS>, ) -> UART4<RX, TX, RTS, CTS>
The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
Combines transmit and receive halves back into a duplex UART
pub fn intenset<F>(&mut self, f: F)
The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
pub fn intenclr<F>(&mut self, f: F)
The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.
pub fn flags(&self) -> R<u16, Reg<u16, _STATUS>>
The sercom::v1::uart module is deprecated, and will be removed in a subsequent release.
Please use the sercom::v2::uart module instead.